@@ -21,8 +21,11 @@ from robot.output.logger import LOGGER
 
 from avocado.core.nrunner.runnable import Runnable
 from avocado.core.plugin_interfaces import Resolver
-from avocado.core.resolver import (ReferenceResolution,
-                                   ReferenceResolutionResult, check_file)
+from avocado.core.resolver import (
+    ReferenceResolution,
+    ReferenceResolutionResult,
+    check_file,
+)
 
 LOGGER.unregister_console_logger()
 
@@ -35,8 +38,9 @@ def find_tests(reference, test_suite):
     test_suite[data.name] = []
     # data.tests is a list
     for test_case in data.tests:  # pylint: disable=E1133
-        test_suite[data.name].append({'test_name': test_case,
-                                      'test_source': data.source})
+        test_suite[data.name].append(
+            {"test_name": test_case, "test_source": data.source}
+        )
 
     # data.suites is a list
     for child_data in data.suites:  # pylint: disable=E1133
@@ -46,17 +50,17 @@ def find_tests(reference, test_suite):
 
 class RobotResolver(Resolver):
 
-    name = 'robot'
-    description = 'Test resolver for Robot Framework tests'
+    name = "robot"
+    description = "Test resolver for Robot Framework tests"
 
     @staticmethod
-    def resolve(reference):
+    def resolve(reference):  # pylint: disable=W0221
 
         # It may be possible to have Robot Framework tests in other
         # types of files such as reStructuredText (.rst), but given
         # that we're not testing that, let's restrict to files ending
         # in .robot files
-        criteria_check = check_file(reference, reference, suffix='.robot')
+        criteria_check = check_file(reference, reference, suffix=".robot")
         if criteria_check is not True:
             return criteria_check
 
@@ -64,15 +68,13 @@ class RobotResolver(Resolver):
         runnables = []
         for key, value in robot_suite.items():
             for robot_test in value:
-                uri = (f"{robot_test['test_source']}:"
-                       f"{key}.{robot_test['test_name']}")
+                uri = f"{robot_test['test_source']}:" f"{key}.{robot_test['test_name']}"
 
-                runnables.append(Runnable('robot', uri=uri))
+                runnables.append(Runnable("robot", uri=uri))
 
         if runnables:
-            return ReferenceResolution(reference,
-                                       ReferenceResolutionResult.SUCCESS,
-                                       runnables)
+            return ReferenceResolution(
+                reference, ReferenceResolutionResult.SUCCESS, runnables
+            )
 
-        return ReferenceResolution(reference,
-                                   ReferenceResolutionResult.NOTFOUND)
+        return ReferenceResolution(reference, ReferenceResolutionResult.NOTFOUND)
